@@ -1,15 +1,10 @@
 """Module and group classes."""
 
+from __future__ import annotations
+
 import asyncio
-from typing import (
-    TYPE_CHECKING,
-    Any,
-    Callable,
-    Optional,
-    Union,
-    cast,
-)
-from collections.abc import Awaitable, Sequence
+from collections.abc import Awaitable, Callable, Sequence
+from typing import TYPE_CHECKING, Any, cast
 
 from pypck import inputs, lcn_defs
 from pypck.helpers import TaskRegistry
@@ -37,13 +32,15 @@ class AbstractConnection:
 
     def __init__(
         self,
-        conn: "PchkConnectionManager",
+        conn: PchkConnectionManager,
         addr: LcnAddr,
-        software_serial: Optional[int] = None,
-    ):
+        software_serial: int | None = None,
+        wants_ack: bool = False,
+    ) -> None:
         """Construct AbstractConnection instance."""
         self.conn = conn
         self.addr = addr
+        self.wants_ack = wants_ack
 
         if software_serial is None:
             software_serial = -1
@@ -70,7 +67,7 @@ class AbstractConnection:
         return self.addr.is_group
 
     @property
-    def serials(self) -> dict[str, Union[int, lcn_defs.HardwareType]]:
+    def serials(self) -> dict[str, int | lcn_defs.HardwareType]:
         """Return serial numbers of a module."""
         return {
             "hardware_serial": -1,
@@ -106,11 +103,11 @@ class AbstractConnection:
         event.set()
         return event.wait()
 
-    async def request_serials(self) -> dict[str, Union[int, lcn_defs.HardwareType]]:
+    async def request_serials(self) -> dict[str, int | lcn_defs.HardwareType]:
         """Request module serials."""
         return self.serials
 
-    async def send_command(self, wants_ack: bool, pck: Union[str, bytes]) -> bool:
+    async def send_command(self, wants_ack: bool, pck: str | bytes) -> bool:
         """Send a command to the module represented by this class.
 
         :param    bool    wants_ack:    Also send a request for acknowledge.
@@ -138,11 +135,11 @@ class AbstractConnection:
         :rtype:      bool
         """
         return await self.send_command(
-            not self.is_group, PckGenerator.dim_output(output_id, percent, ramp)
+            self.wants_ack, PckGenerator.dim_output(output_id, percent, ramp)
         )
 
     async def dim_all_outputs(
-        self, percent: float, ramp: int, software_serial: Optional[int] = None
+        self, percent: float, ramp: int, software_serial: int | None = None
     ) -> bool:
         """Send a dim command for all output-ports.
 
@@ -159,7 +156,7 @@ class AbstractConnection:
             software_serial = self.software_serial
 
         return await self.send_command(
-            not self.is_group,
+            self.wants_ack,
             PckGenerator.dim_all_outputs(percent, ramp, software_serial),
         )
 
@@ -174,7 +171,7 @@ class AbstractConnection:
         :rtype:      bool
         """
         return await self.send_command(
-            not self.is_group, PckGenerator.rel_output(output_id, percent)
+            self.wants_ack, PckGenerator.rel_output(output_id, percent)
         )
 
     async def toggle_output(self, output_id: int, ramp: int) -> bool:
@@ -189,7 +186,7 @@ class AbstractConnection:
         :rtype:      bool
         """
         return await self.send_command(
-            not self.is_group, PckGenerator.toggle_output(output_id, ramp)
+            self.wants_ack, PckGenerator.toggle_output(output_id, ramp)
         )
 
     async def toggle_all_outputs(self, ramp: int) -> bool:
@@ -203,7 +200,7 @@ class AbstractConnection:
         :rtype:      bool
         """
         return await self.send_command(
-            not self.is_group, PckGenerator.toggle_all_outputs(ramp)
+            self.wants_ack, PckGenerator.toggle_all_outputs(ramp)
         )
 
     async def control_relays(self, states: list[lcn_defs.RelayStateModifier]) -> bool:
@@ -216,7 +213,7 @@ class AbstractConnection:
         :rtype:      bool
         """
         return await self.send_command(
-            not self.is_group, PckGenerator.control_relays(states)
+            self.wants_ack, PckGenerator.control_relays(states)
         )
 
     async def control_relays_timer(
@@ -232,7 +229,7 @@ class AbstractConnection:
         :rtype:      bool
         """
         return await self.send_command(
-            not self.is_group, PckGenerator.control_relays_timer(time_msec, states)
+            self.wants_ack, PckGenerator.control_relays_timer(time_msec, states)
         )
 
     async def control_motors_relays(
@@ -247,13 +244,13 @@ class AbstractConnection:
         :rtype:      bool
         """
         return await self.send_command(
-            not self.is_group, PckGenerator.control_motors_relays(states)
+            self.wants_ack, PckGenerator.control_motors_relays(states)
         )
 
     async def control_motors_outputs(
         self,
         state: lcn_defs.MotorStateModifier,
-        reverse_time: Optional[lcn_defs.MotorReverseTime] = None,
+        reverse_time: lcn_defs.MotorReverseTime | None = None,
     ) -> bool:
         """Send a command to control a motor via output ports 1+2.
 
@@ -266,7 +263,7 @@ class AbstractConnection:
         :rtype:      bool
         """
         return await self.send_command(
-            not self.is_group,
+            self.wants_ack,
             PckGenerator.control_motors_outputs(state, reverse_time),
         )
 
@@ -276,7 +273,7 @@ class AbstractConnection:
         scene_id: int,
         output_ports: Sequence[lcn_defs.OutputPort] = (),
         relay_ports: Sequence[lcn_defs.RelayPort] = (),
-        ramp: Optional[int] = None,
+        ramp: int | None = None,
     ) -> bool:
         """Activate the stored states for the given scene.
 
@@ -292,7 +289,7 @@ class AbstractConnection:
         :rtype:      bool
         """
         success = await self.send_command(
-            not self.is_group, PckGenerator.change_scene_register(register_id)
+            self.wants_ack, PckGenerator.change_scene_register(register_id)
         )
         if not success:
             return False
@@ -300,12 +297,12 @@ class AbstractConnection:
         result = True
         if output_ports:
             result &= await self.send_command(
-                not self.is_group,
+                self.wants_ack,
                 PckGenerator.activate_scene_output(scene_id, output_ports, ramp),
             )
         if relay_ports:
             result &= await self.send_command(
-                not self.is_group,
+                self.wants_ack,
                 PckGenerator.activate_scene_relay(scene_id, relay_ports),
             )
         return result
@@ -316,7 +313,7 @@ class AbstractConnection:
         scene_id: int,
         output_ports: Sequence[lcn_defs.OutputPort] = (),
         relay_ports: Sequence[lcn_defs.RelayPort] = (),
-        ramp: Optional[int] = None,
+        ramp: int | None = None,
     ) -> bool:
         """Store states in the given scene.
 
@@ -332,7 +329,7 @@ class AbstractConnection:
         :rtype:      bool
         """
         success = await self.send_command(
-            not self.is_group, PckGenerator.change_scene_register(register_id)
+            self.wants_ack, PckGenerator.change_scene_register(register_id)
         )
 
         if not success:
@@ -341,12 +338,12 @@ class AbstractConnection:
         result = True
         if output_ports:
             result &= await self.send_command(
-                not self.is_group,
+                self.wants_ack,
                 PckGenerator.store_scene_output(scene_id, output_ports, ramp),
             )
         if relay_ports:
             result &= await self.send_command(
-                not self.is_group,
+                self.wants_ack,
                 PckGenerator.store_scene_relay(scene_id, relay_ports),
             )
         return result
@@ -369,7 +366,7 @@ class AbstractConnection:
         :rtype:      bool
         """
         return await self.send_command(
-            not self.is_group,
+            self.wants_ack,
             PckGenerator.store_scene_outputs_direct(
                 register_id, scene_id, percents, ramps
             ),
@@ -378,9 +375,9 @@ class AbstractConnection:
     async def var_abs(
         self,
         var: lcn_defs.Var,
-        value: Union[float, lcn_defs.VarValue],
+        value: float | lcn_defs.VarValue,
         unit: lcn_defs.VarUnit = lcn_defs.VarUnit.NATIVE,
-        software_serial: Optional[int] = None,
+        software_serial: int | None = None,
     ) -> bool:
         """Send a command to set the absolute value to a variable.
 
@@ -403,28 +400,28 @@ class AbstractConnection:
             if self.addr_id == 4 and self.is_group:
                 # group 4 are status messages
                 return await self.send_command(
-                    not self.is_group,
+                    self.wants_ack,
                     PckGenerator.update_status_var(var, value.to_native()),
                 )
             # We fake the missing command by using reset and relative
             # commands.
             success = await self.send_command(
-                not self.is_group, PckGenerator.var_reset(var, software_serial)
+                self.wants_ack, PckGenerator.var_reset(var, software_serial)
             )
             if not success:
                 return False
             return await self.send_command(
-                not self.is_group,
+                self.wants_ack,
                 PckGenerator.var_rel(
                     var, lcn_defs.RelVarRef.CURRENT, value.to_native(), software_serial
                 ),
             )
         return await self.send_command(
-            not self.is_group, PckGenerator.var_abs(var, value.to_native())
+            self.wants_ack, PckGenerator.var_abs(var, value.to_native())
         )
 
     async def var_reset(
-        self, var: lcn_defs.Var, software_serial: Optional[int] = None
+        self, var: lcn_defs.Var, software_serial: int | None = None
     ) -> bool:
         """Send a command to reset the variable value.
 
@@ -438,16 +435,16 @@ class AbstractConnection:
             software_serial = self.software_serial
 
         return await self.send_command(
-            not self.is_group, PckGenerator.var_reset(var, software_serial)
+            self.wants_ack, PckGenerator.var_reset(var, software_serial)
         )
 
     async def var_rel(
         self,
         var: lcn_defs.Var,
-        value: Union[float, lcn_defs.VarValue],
+        value: float | lcn_defs.VarValue,
         unit: lcn_defs.VarUnit = lcn_defs.VarUnit.NATIVE,
         value_ref: lcn_defs.RelVarRef = lcn_defs.RelVarRef.CURRENT,
-        software_serial: Optional[int] = None,
+        software_serial: int | None = None,
     ) -> bool:
         """Send a command to change the value of a variable.
 
@@ -467,22 +464,27 @@ class AbstractConnection:
             software_serial = self.software_serial
 
         return await self.send_command(
-            not self.is_group,
+            self.wants_ack,
             PckGenerator.var_rel(var, value_ref, value.to_native(), software_serial),
         )
 
-    async def lock_regulator(self, reg_id: int, state: bool) -> bool:
+    async def lock_regulator(
+        self, reg_id: int, state: bool, target_value: float = -1
+    ) -> bool:
         """Send a command to lock a regulator.
 
         :param    int        reg_id:        Regulator id
         :param    bool       state:         Lock state (locked=True,
                                             unlocked=False)
-
+        :param    float        target_value:  Target value in percent (use -1 to ignore)
         :returns:    True if command was sent successfully, False otherwise
         :rtype:      bool
         """
         return await self.send_command(
-            not self.is_group, PckGenerator.lock_regulator(reg_id, state)
+            self.wants_ack,
+            PckGenerator.lock_regulator(
+                reg_id, state, self.software_serial, target_value
+            ),
         )
 
     async def control_led(
@@ -494,7 +496,7 @@ class AbstractConnection:
         :param    LedStatus    state:      Led status
         """
         return await self.send_command(
-            not self.is_group, PckGenerator.control_led(led.value, state)
+            self.wants_ack, PckGenerator.control_led(led.value, state)
         )
 
     async def send_keys(
@@ -517,7 +519,7 @@ class AbstractConnection:
                 cmds[table_id] = cmd
                 results.append(
                     await self.send_command(
-                        not self.is_group, PckGenerator.send_keys(cmds, key_states)
+                        self.wants_ack, PckGenerator.send_keys(cmds, key_states)
                     )
                 )
         return results
@@ -542,7 +544,7 @@ class AbstractConnection:
             if True in key_states:
                 results.append(
                     await self.send_command(
-                        not self.is_group,
+                        self.wants_ack,
                         PckGenerator.send_keys_hit_deferred(
                             table_id, delay_time, delay_unit, key_states
                         ),
@@ -563,7 +565,7 @@ class AbstractConnection:
         :rtype:      bool
         """
         return await self.send_command(
-            not self.is_group, PckGenerator.lock_keys(table_id, states)
+            self.wants_ack, PckGenerator.lock_keys(table_id, states)
         )
 
     async def lock_keys_tab_a_temporary(
@@ -580,7 +582,7 @@ class AbstractConnection:
         :rtype:      bool
         """
         return await self.send_command(
-            not self.is_group,
+            self.wants_ack,
             PckGenerator.lock_keys_tab_a_temporary(delay_time, delay_unit, states),
         )
 
@@ -608,7 +610,7 @@ class AbstractConnection:
         result = True
         for part_id, part in enumerate(parts):
             result &= await self.send_command(
-                not self.is_group,
+                self.wants_ack,
                 PckGenerator.dyn_text_part(row_id, part_id, part),
             )
         return result
@@ -622,9 +624,7 @@ class AbstractConnection:
         :returns:    True if command was sent successfully, False otherwise
         :rtype:      bool
         """
-        return await self.send_command(
-            not self.is_group, PckGenerator.beep(sound, count)
-        )
+        return await self.send_command(self.wants_ack, PckGenerator.beep(sound, count))
 
     async def ping(self) -> bool:
         """Send a command that does nothing and request an acknowledgement."""
@@ -638,7 +638,7 @@ class AbstractConnection:
         :returns:    True if command was sent successfully, False otherwise
         :rtype:      bool
         """
-        return await self.send_command(not self.is_group, pck)
+        return await self.send_command(self.wants_ack, pck)
 
 
 class GroupConnection(AbstractConnection):
@@ -649,20 +649,20 @@ class GroupConnection(AbstractConnection):
 
     def __init__(
         self,
-        conn: "PchkConnectionManager",
+        conn: PchkConnectionManager,
         addr: LcnAddr,
         software_serial: int = 0x170206,
     ):
         """Construct GroupConnection instance."""
         assert addr.is_group
-        super().__init__(conn, addr, software_serial=software_serial)
+        super().__init__(conn, addr, software_serial=software_serial, wants_ack=False)
 
     async def var_abs(
         self,
         var: lcn_defs.Var,
-        value: Union[float, lcn_defs.VarValue],
+        value: float | lcn_defs.VarValue,
         unit: lcn_defs.VarUnit = lcn_defs.VarUnit.NATIVE,
-        software_serial: Optional[int] = None,
+        software_serial: int | None = None,
     ) -> bool:
         """Send a command to set the absolute value to a variable.
 
@@ -686,7 +686,7 @@ class GroupConnection(AbstractConnection):
         return result
 
     async def var_reset(
-        self, var: lcn_defs.Var, software_serial: Optional[int] = None
+        self, var: lcn_defs.Var, software_serial: int | None = None
     ) -> bool:
         """Send a command to reset the variable value.
 
@@ -707,10 +707,10 @@ class GroupConnection(AbstractConnection):
     async def var_rel(
         self,
         var: lcn_defs.Var,
-        value: Union[float, lcn_defs.VarValue],
+        value: float | lcn_defs.VarValue,
         unit: lcn_defs.VarUnit = lcn_defs.VarUnit.NATIVE,
         value_ref: lcn_defs.RelVarRef = lcn_defs.RelVarRef.CURRENT,
-        software_serial: Optional[int] = None,
+        software_serial: int | None = None,
     ) -> bool:
         """Send a command to change the value of a variable.
 
@@ -751,57 +751,56 @@ class ModuleConnection(AbstractConnection):
 
     def __init__(
         self,
-        conn: "PchkConnectionManager",
+        conn: PchkConnectionManager,
         addr: LcnAddr,
         activate_status_requests: bool = False,
         has_s0_enabled: bool = False,
-        software_serial: Optional[int] = None,
+        software_serial: int | None = None,
+        wants_ack: bool = True,
     ):
         """Construct ModuleConnection instance."""
         assert not addr.is_group
-        super().__init__(conn, addr, software_serial=software_serial)
+        super().__init__(
+            conn, addr, software_serial=software_serial, wants_ack=wants_ack
+        )
         self.activate_status_requests = activate_status_requests
         self.has_s0_enabled = has_s0_enabled
 
         self.input_callbacks: set[Callable[[inputs.Input], None]] = set()
 
         # List of queued acknowledge codes from the LCN modules.
-        self.acknowledges: "asyncio.Queue[int]" = asyncio.Queue()
+        self.acknowledges: asyncio.Queue[int] = asyncio.Queue()
 
         # RequestHandlers
         num_tries: int = self.conn.settings["NUM_TRIES"]
-        timeout_msec: int = self.conn.settings["DEFAULT_TIMEOUT_MSEC"]
+        timeout: int = self.conn.settings["DEFAULT_TIMEOUT"]
 
         # Serial Number request
         self.serials_request_handler = SerialRequestHandler(
             self,
             num_tries,
-            timeout_msec,
+            timeout,
             software_serial=software_serial,
         )
 
         # Name, Comment, OemText requests
-        self.name_request_handler = NameRequestHandler(self, num_tries, timeout_msec)
-        self.comment_request_handler = CommentRequestHandler(
-            self, num_tries, timeout_msec
-        )
-        self.oem_text_request_handler = OemTextRequestHandler(
-            self, num_tries, timeout_msec
-        )
+        self.name_request_handler = NameRequestHandler(self, num_tries, timeout)
+        self.comment_request_handler = CommentRequestHandler(self, num_tries, timeout)
+        self.oem_text_request_handler = OemTextRequestHandler(self, num_tries, timeout)
 
         # Group membership request
         self.static_groups_request_handler = GroupMembershipStaticRequestHandler(
-            self, num_tries, timeout_msec
+            self, num_tries, timeout
         )
         self.dynamic_groups_request_handler = GroupMembershipDynamicRequestHandler(
-            self, num_tries, timeout_msec
+            self, num_tries, timeout
         )
 
         self.status_requests_handler = StatusRequestsHandler(self)
         if self.activate_status_requests:
             self.task_registry.create_task(self.activate_status_request_handlers())
 
-    async def send_command(self, wants_ack: bool, pck: Union[str, bytes]) -> bool:
+    async def send_command(self, wants_ack: bool, pck: str | bytes) -> bool:
         """Send a command to the module represented by this class.
 
         :param    bool    wants_ack:    Also send a request for acknowledge.
@@ -816,7 +815,7 @@ class ModuleConnection(AbstractConnection):
     # ## Retry logic if an acknowledge is requested
     # ##
 
-    async def send_command_with_ack(self, pck: Union[str, bytes]) -> bool:
+    async def send_command_with_ack(self, pck: str | bytes) -> bool:
         """Send a PCK command and ensure receiving of an acknowledgement.
 
         Resends the PCK command if no acknowledgement has been received
@@ -832,7 +831,7 @@ class ModuleConnection(AbstractConnection):
             try:
                 code = await asyncio.wait_for(
                     self.acknowledges.get(),
-                    timeout=self.conn.settings["DEFAULT_TIMEOUT_MSEC"] / 1000,
+                    timeout=self.conn.settings["DEFAULT_TIMEOUT"],
                 )
             except asyncio.TimeoutError:
                 count += 1
@@ -951,7 +950,7 @@ class ModuleConnection(AbstractConnection):
     # ## properties
 
     @property
-    def serials(self) -> dict[str, Union[int, lcn_defs.HardwareType]]:
+    def serials(self) -> dict[str, int | lcn_defs.HardwareType]:
         """Return serials number information."""
         return self.serials_request_handler.serials
 
@@ -992,7 +991,7 @@ class ModuleConnection(AbstractConnection):
         """Check if serials have already been received from module."""
         return self.serials_request_handler.serial_known.wait()
 
-    async def request_serials(self) -> dict[str, Union[int, lcn_defs.HardwareType]]:
+    async def request_serials(self) -> dict[str, int | lcn_defs.HardwareType]:
         """Request module serials."""
         return await self.serials_request_handler.request()
 
