@@ -1,7 +1,9 @@
 """Handlers for requests."""
 
+from __future__ import annotations
+
 import asyncio
-from typing import TYPE_CHECKING, Any, Optional, Union
+from typing import TYPE_CHECKING, Any
 
 from pypck import inputs, lcn_defs
 from pypck.helpers import TaskRegistry
@@ -18,14 +20,14 @@ class RequestHandler:
 
     def __init__(
         self,
-        addr_conn: "ModuleConnection",
+        addr_conn: ModuleConnection,
         num_tries: int = 3,
-        timeout_msec: int = 1500,
+        timeout: float = 1.5,
     ):
         """Initialize class instance."""
         self.addr_conn = addr_conn
 
-        self.trh = TimeoutRetryHandler(self.task_registry, num_tries, timeout_msec)
+        self.trh = TimeoutRetryHandler(self.task_registry, num_tries, timeout)
         self.trh.set_timeout_callback(self.timeout)
 
         # callback
@@ -65,10 +67,10 @@ class SerialRequestHandler(RequestHandler):
 
     def __init__(
         self,
-        addr_conn: "ModuleConnection",
+        addr_conn: ModuleConnection,
         num_tries: int = 3,
-        timeout_msec: int = 1500,
-        software_serial: Optional[int] = None,
+        timeout: float = 1.5,
+        software_serial: int | None = None,
     ):
         """Initialize class instance."""
         self.hardware_serial = -1
@@ -81,7 +83,7 @@ class SerialRequestHandler(RequestHandler):
         # events
         self.serial_known = asyncio.Event()
 
-        super().__init__(addr_conn, num_tries, timeout_msec)
+        super().__init__(addr_conn, num_tries, timeout)
 
     async def async_process_input(self, inp: inputs.Input) -> None:
         """Process incoming input object.
@@ -104,7 +106,7 @@ class SerialRequestHandler(RequestHandler):
         else:
             self.serial_known.set()
 
-    async def request(self) -> dict[str, Union[int, lcn_defs.HardwareType]]:
+    async def request(self) -> dict[str, int | lcn_defs.HardwareType]:
         """Request serial number."""
         await self.addr_conn.conn.segment_scan_completed_event.wait()
         self.serial_known.clear()
@@ -113,7 +115,7 @@ class SerialRequestHandler(RequestHandler):
         return self.serials
 
     @property
-    def serials(self) -> dict[str, Union[int, lcn_defs.HardwareType]]:
+    def serials(self) -> dict[str, int | lcn_defs.HardwareType]:
         """Return serial numbers of a module."""
         return {
             "hardware_serial": self.hardware_serial,
@@ -128,19 +130,19 @@ class NameRequestHandler(RequestHandler):
 
     def __init__(
         self,
-        addr_conn: "ModuleConnection",
+        addr_conn: ModuleConnection,
         num_tries: int = 3,
-        timeout_msec: int = 1500,
+        timeout: float = 1.5,
     ):
         """Initialize class instance."""
-        self._name: list[Optional[str]] = [None] * 2
+        self._name: list[str | None] = [None] * 2
         self.name_known = asyncio.Event()
 
-        super().__init__(addr_conn, num_tries, timeout_msec)
+        super().__init__(addr_conn, num_tries, timeout)
 
         self.trhs = []
         for block_id in range(2):
-            trh = TimeoutRetryHandler(self.task_registry, num_tries, timeout_msec)
+            trh = TimeoutRetryHandler(self.task_registry, num_tries, timeout)
             trh.set_timeout_callback(self.timeout, block_id=block_id)
             self.trhs.append(trh)
 
@@ -182,7 +184,7 @@ class NameRequestHandler(RequestHandler):
         return self.name
 
     # pylint: disable=arguments-differ
-    async def cancel(self, block_id: Optional[int] = None) -> None:
+    async def cancel(self, block_id: int | None = None) -> None:
         """Cancel name request task."""
         if block_id is None:  # cancel all
             for trh in self.trhs:
@@ -201,19 +203,19 @@ class CommentRequestHandler(RequestHandler):
 
     def __init__(
         self,
-        addr_conn: "ModuleConnection",
+        addr_conn: ModuleConnection,
         num_tries: int = 3,
-        timeout_msec: int = 1500,
+        timeout: float = 1.5,
     ):
         """Initialize class instance."""
-        self._comment: list[Optional[str]] = [None] * 3
+        self._comment: list[str | None] = [None] * 3
         self.comment_known = asyncio.Event()
 
-        super().__init__(addr_conn, num_tries, timeout_msec)
+        super().__init__(addr_conn, num_tries, timeout)
 
         self.trhs = []
         for block_id in range(3):
-            trh = TimeoutRetryHandler(self.task_registry, num_tries, timeout_msec)
+            trh = TimeoutRetryHandler(self.task_registry, num_tries, timeout)
             trh.set_timeout_callback(self.timeout, block_id=block_id)
             self.trhs.append(trh)
 
@@ -255,7 +257,7 @@ class CommentRequestHandler(RequestHandler):
         return self.comment
 
     # pylint: disable=arguments-differ
-    async def cancel(self, block_id: Optional[int] = None) -> None:
+    async def cancel(self, block_id: int | None = None) -> None:
         """Cancel comment request task."""
         if block_id is None:  # cancel all
             for trh in self.trhs:
@@ -274,19 +276,19 @@ class OemTextRequestHandler(RequestHandler):
 
     def __init__(
         self,
-        addr_conn: "ModuleConnection",
+        addr_conn: ModuleConnection,
         num_tries: int = 3,
-        timeout_msec: int = 1500,
+        timeout: float = 1.5,
     ):
         """Initialize class instance."""
-        self._oem_text: list[Optional[str]] = [None] * 4
+        self._oem_text: list[str | None] = [None] * 4
         self.oem_text_known = asyncio.Event()
 
-        super().__init__(addr_conn, num_tries, timeout_msec)
+        super().__init__(addr_conn, num_tries, timeout)
 
         self.trhs = []
         for block_id in range(4):
-            trh = TimeoutRetryHandler(self.task_registry, num_tries, timeout_msec)
+            trh = TimeoutRetryHandler(self.task_registry, num_tries, timeout)
             trh.set_timeout_callback(self.timeout, block_id=block_id)
             self.trhs.append(trh)
 
@@ -328,7 +330,7 @@ class OemTextRequestHandler(RequestHandler):
         return self.oem_text
 
     # pylint: disable=arguments-differ
-    async def cancel(self, block_id: Optional[int] = None) -> None:
+    async def cancel(self, block_id: int | None = None) -> None:
         """Cancel OEM text request task."""
         if block_id is None:  # cancel all
             for trh in self.trhs:
@@ -351,15 +353,15 @@ class GroupMembershipStaticRequestHandler(RequestHandler):
 
     def __init__(
         self,
-        addr_conn: "ModuleConnection",
+        addr_conn: ModuleConnection,
         num_tries: int = 3,
-        timeout_msec: int = 1500,
+        timeout: float = 1.5,
     ):
         """Initialize class instance."""
         self.groups: set[LcnAddr] = set()
         self.groups_known = asyncio.Event()
 
-        super().__init__(addr_conn, num_tries, timeout_msec)
+        super().__init__(addr_conn, num_tries, timeout)
 
     async def async_process_input(self, inp: inputs.Input) -> None:
         """Process incoming input object.
@@ -395,15 +397,15 @@ class GroupMembershipDynamicRequestHandler(RequestHandler):
 
     def __init__(
         self,
-        addr_conn: "ModuleConnection",
+        addr_conn: ModuleConnection,
         num_tries: int = 3,
-        timeout_msec: int = 1500,
+        timeout: float = 1.5,
     ):
         """Initialize class instance."""
         self.groups: set[LcnAddr] = set()
         self.groups_known = asyncio.Event()
 
-        super().__init__(addr_conn, num_tries, timeout_msec)
+        super().__init__(addr_conn, num_tries, timeout)
 
     async def async_process_input(self, inp: inputs.Input) -> None:
         """Process incoming input object.
@@ -437,7 +439,7 @@ class GroupMembershipDynamicRequestHandler(RequestHandler):
 class StatusRequestsHandler:
     """Manages all status requests for variables, software version, ..."""
 
-    def __init__(self, addr_conn: "ModuleConnection"):
+    def __init__(self, addr_conn: ModuleConnection):
         """Construct StatusRequestHandler instance."""
         self.addr_conn = addr_conn
         self.settings = addr_conn.conn.settings
@@ -451,14 +453,14 @@ class StatusRequestsHandler:
             trh = TimeoutRetryHandler(
                 self.task_registry,
                 -1,
-                self.settings["MAX_STATUS_EVENTBASED_VALUEAGE_MSEC"],
+                self.settings["MAX_STATUS_EVENTBASED_VALUEAGE"],
             )
             trh.set_timeout_callback(self.request_status_outputs_timeout, output_port)
             self.request_status_outputs.append(trh)
 
         # Relay request status (all 8)
         self.request_status_relays = TimeoutRetryHandler(
-            self.task_registry, -1, self.settings["MAX_STATUS_EVENTBASED_VALUEAGE_MSEC"]
+            self.task_registry, -1, self.settings["MAX_STATUS_EVENTBASED_VALUEAGE"]
         )
         self.request_status_relays.set_timeout_callback(
             self.request_status_relays_timeout
@@ -466,7 +468,7 @@ class StatusRequestsHandler:
 
         # Binary-sensors request status (all 8)
         self.request_status_bin_sensors = TimeoutRetryHandler(
-            self.task_registry, -1, self.settings["MAX_STATUS_EVENTBASED_VALUEAGE_MSEC"]
+            self.task_registry, -1, self.settings["MAX_STATUS_EVENTBASED_VALUEAGE"]
         )
         self.request_status_bin_sensors.set_timeout_callback(
             self.request_status_bin_sensors_timeout
@@ -481,7 +483,7 @@ class StatusRequestsHandler:
                 self.request_status_vars[var] = TimeoutRetryHandler(
                     self.task_registry,
                     -1,
-                    self.settings["MAX_STATUS_EVENTBASED_VALUEAGE_MSEC"],
+                    self.settings["MAX_STATUS_EVENTBASED_VALUEAGE"],
                 )
                 self.request_status_vars[var].set_timeout_callback(
                     self.request_status_var_timeout, var=var
@@ -489,7 +491,7 @@ class StatusRequestsHandler:
 
         # LEDs and logic-operations request status (all 12+4).
         self.request_status_leds_and_logic_ops = TimeoutRetryHandler(
-            self.task_registry, -1, self.settings["MAX_STATUS_POLLED_VALUEAGE_MSEC"]
+            self.task_registry, -1, self.settings["MAX_STATUS_POLLED_VALUEAGE"]
         )
         self.request_status_leds_and_logic_ops.set_timeout_callback(
             self.request_status_leds_and_logic_ops_timeout
@@ -497,7 +499,7 @@ class StatusRequestsHandler:
 
         # Key lock-states request status (all tables, A-D).
         self.request_status_locked_keys = TimeoutRetryHandler(
-            self.task_registry, -1, self.settings["MAX_STATUS_POLLED_VALUEAGE_MSEC"]
+            self.task_registry, -1, self.settings["MAX_STATUS_POLLED_VALUEAGE"]
         )
         self.request_status_locked_keys.set_timeout_callback(
             self.request_status_locked_keys_timeout
@@ -548,7 +550,7 @@ class StatusRequestsHandler:
             )
 
     async def request_status_var_timeout(
-        self, failed: bool = False, var: Optional[lcn_defs.Var] = None
+        self, failed: bool = False, var: lcn_defs.Var | None = None
     ) -> None:
         """Is called on variable status request timeout."""
         assert var is not None
@@ -595,10 +597,10 @@ class StatusRequestsHandler:
             # wait until we know the software version
             await self.addr_conn.serial_known
             if self.addr_conn.software_serial >= 0x170206:
-                timeout_msec = self.settings["MAX_STATUS_EVENTBASED_VALUEAGE_MSEC"]
+                timeout = self.settings["MAX_STATUS_EVENTBASED_VALUEAGE"]
             else:
-                timeout_msec = self.settings["MAX_STATUS_POLLED_VALUEAGE_MSEC"]
-            self.request_status_vars[item].set_timeout_msec(timeout_msec)
+                timeout = self.settings["MAX_STATUS_POLLED_VALUEAGE"]
+            self.request_status_vars[item].set_timeout(timeout)
             self.request_status_vars[item].activate()
         elif item in lcn_defs.OutputPort:
             self.request_status_outputs[item.value].activate()
